@@ -134,7 +134,7 @@ public abstract class ContextAbstraction extends UserAbstraction {
     private static final String SCHEMA_OPT_DESC = "The schema name, where the context will be created. This bypasses any weight balancing. Must not be set, if \"schema-strategy\" is set.";
     private static final String SCHEMA_OPT = "schema";
 
-    private static final String SCHEMA_STRATEGY_OPT_DESC = "The schema select strategy. \"automatic\" for automatic selection (default), \"in-memory\" for in memory selection. Must not be set, if \"schema\" option is set.";
+    private static final String SCHEMA_STRATEGY_OPT_DESC = "The schema select strategy. \"automatic\" for automatic selection (default). Deprecated: \"in-memory\" is no more supported and falls-back to \"automatic\". Must not be set, if \"schema\" option is set.";
     private static final String SCHEMA_STRATEGY_OPT = "schema-strategy";
 
     public final static char OPT_CONTEXT_ADD_LOGIN_MAPPINGS_SHORT = 'L';
@@ -162,7 +162,7 @@ public abstract class ContextAbstraction extends UserAbstraction {
     protected String schemaStrategy;
 
     protected static final String SCHEMA_NAME_AND_SCHEMA_STRATEGY_ERROR = "You can not specify \"schema\" and \"schema-strategy\" at the same time.";
-    protected static final String SCHEMA_NAME_ERROR = "Invalid value for \"schema\". Available values: \"automatic\", \"in-memory\"";
+    protected static final String SCHEMA_NAME_ERROR = "Invalid value for \"schema\". Available value: \"automatic\"";
 
     protected Integer filestoreid = null;
 
@@ -270,7 +270,11 @@ public abstract class ContextAbstraction extends UserAbstraction {
         this.contextQuotaOption = setShortLongOpt(parser, OPT_QUOTA_SHORT, OPT_QUOTA_LONG, OPT_NAME_CONTEXT_QUOTA_DESCRIPTION, true, convertBooleantoTriState(required));
     }
 
-    protected void sysoutOutput(final Context[] ctxs, final AdminParser parser) throws InvalidDataException {
+    protected void sysoutOutput(Context[] ctxs, AdminParser parser) throws InvalidDataException {
+        sysoutOutput(ctxs, false, parser);
+    }
+
+    protected void sysoutOutput(Context[] ctxs, boolean continuation, AdminParser parser) throws InvalidDataException {
         final ArrayList<ArrayList<String>> data = new ArrayList<ArrayList<String>>();
         for (final Context ctx : ctxs) {
             data.add(makeData(ctx, new ClosureInterface() {
@@ -306,7 +310,7 @@ public abstract class ContextAbstraction extends UserAbstraction {
         columnnames.add("lmappings");
         columnnames.addAll(humanReadableColumnsOfAllExtensions);
 
-        doOutput(alignment.toArray(new String[alignment.size()]), columnnames.toArray(new String[columnnames.size()]), data);
+        doOutput(alignment.toArray(new String[alignment.size()]), columnnames.toArray(new String[columnnames.size()]), continuation, data);
     }
 
     protected void sysoutOutput(Quota[] quotas) throws InvalidDataException {
@@ -339,10 +343,14 @@ public abstract class ContextAbstraction extends UserAbstraction {
         columnnames.add("module");
         columnnames.add("qlimit");
 
-        doOutput(alignment.toArray(new String[alignment.size()]), columnnames.toArray(new String[columnnames.size()]), data);
+        doOutput(alignment.toArray(new String[alignment.size()]), columnnames.toArray(new String[columnnames.size()]), false, data);
     }
 
-    protected void precsvinfos(final Context[] ctxs, final AdminParser parser) throws InvalidDataException {
+    protected void precsvinfos(Context[] ctxs, AdminParser parser) throws InvalidDataException {
+        precsvinfos(ctxs, false, parser);
+    }
+
+    protected void precsvinfos(Context[] ctxs, boolean continuation, AdminParser parser) throws InvalidDataException {
         // needed for csv output, KEEP AN EYE ON ORDER!!!
         final ArrayList<String> columns = new ArrayList<String>();
         columns.add("id");
@@ -368,7 +376,7 @@ public abstract class ContextAbstraction extends UserAbstraction {
             }, true));
         }
 
-        doCSVOutput(columns, data);
+        doCSVOutput(columns, continuation, data);
     }
 
     protected void precsvinfos(Quota[] quotas) throws InvalidDataException {
@@ -397,7 +405,7 @@ public abstract class ContextAbstraction extends UserAbstraction {
             data.add(curData);
         }
 
-        doCSVOutput(columns, data);
+        doCSVOutput(columns, false, data);
     }
 
     protected void setDatabaseIDOption(final AdminParser parser) {
@@ -570,8 +578,9 @@ public abstract class ContextAbstraction extends UserAbstraction {
             String strategyName = nextLine[strategyId];
             if (strategyName.equals("automatic")) {
                 return SchemaSelectStrategy.automatic();
-            } else if (strategyName.equals("in-memory")) {
-                return SchemaSelectStrategy.inMemory();
+            } else if (schemaStrategy.equals("in-memory")) {
+                // Fall-back to "automatic"
+                return SchemaSelectStrategy.automatic();
             } else {
                 throw new InvalidDataException(SCHEMA_NAME_ERROR);
             }
