@@ -53,27 +53,24 @@ import java.io.BufferedReader;
 import java.io.BufferedWriter;
 import java.io.Console;
 import java.io.File;
+import java.io.FileInputStream;
 import java.io.FileNotFoundException;
-import java.io.FileReader;
+import java.io.FileOutputStream;
 import java.io.IOException;
 import java.io.InputStreamReader;
 import java.io.OutputStreamWriter;
-import java.io.PrintWriter;
+import java.io.UnsupportedEncodingException;
+import java.io.Writer;
 import java.nio.charset.Charset;
-import java.util.HashMap;
+import java.util.EnumMap;
 import java.util.LinkedList;
 import java.util.List;
 import java.util.Map;
 import org.apache.commons.cli.CommandLine;
-import org.apache.commons.cli.CommandLineParser;
-import org.apache.commons.cli.HelpFormatter;
-import org.apache.commons.cli.Option;
-import org.apache.commons.cli.OptionBuilder;
 import org.apache.commons.cli.Options;
-import org.apache.commons.cli.ParseException;
-import org.apache.commons.cli.PosixParser;
+import com.openexchange.cli.AbstractCLI;
 import com.openexchange.exception.OXException;
-import com.openexchange.java.Streams;
+import com.openexchange.java.Charsets;
 import com.openexchange.java.Strings;
 import com.openexchange.passwordmechs.IPasswordMech;
 import com.openexchange.passwordmechs.PasswordMech;
@@ -83,61 +80,85 @@ import com.openexchange.passwordmechs.PasswordMech;
  *
  * @author <a href="mailto:ioannis.chouklis@open-xchange.com">Ioannis Chouklis</a>
  */
-public class GenerateMasterPasswordCLT {
-
-    private enum Parameter {
-        adminuser, adminpass, encryption, mpasswdfile
-    }
-
-    private static final Options options = new Options();
-    static {
-        options.addOption(createOption("A", "adminuser", true, false, "Account name of superadmin (Default: oxadminmaster)", false));
-        options.addOption(createOption("P", "adminpass", true, false, "Password of superadmin", false));
-        options.addOption(createOption("f", "mpasswdfile", true, false, "Path to mpasswd (Default: /opt/open-xchange/etc/mpasswd)", false));
-        options.addOption(createOption("e", "encryption", true, false, "Encryption algorithm to use for the password (Default: bcrypt)", false));
-        options.addOption(createOption("h", "help", false, false, "Prints this help text", false));
-    }
-
-    /**
-     * Create an {@link Option} with the {@link OptionBuilder}
-     *
-     * @param shortName short name of the option
-     * @param longName long name of the option
-     * @param hasArgs whether it has arguments
-     * @param hasOptArgs whether it has optional arguments
-     * @param description short description
-     * @param mandatory whether it is mandatory
-     * @return
-     */
-    @SuppressWarnings("static-access")
-    private static final Option createOption(String shortName, String longName, boolean hasArgs, boolean hasOptArgs, String description, boolean mandatory) {
-        return OptionBuilder.withLongOpt(longName).hasArg(hasArgs).withDescription(description).isRequired(mandatory).create(shortName);
-    }
+public class GenerateMasterPasswordCLT extends AbstractCLI<Void, Map<GenerateMasterPasswordCLT.Parameter, String>> {
 
     /**
      * @param args
      */
     public static void main(String[] args) {
-        CommandLineParser parser = new PosixParser();
+        new GenerateMasterPasswordCLT().execute(args);
+    }
+
+    private static final String SYNTAX = "generatempasswd [-A <adminuser>] [-P <adminpassword>] [-e <encryption>] [-f </path/for/mpasswdfile>]";
+    private static final String FOOTER = "\n\nValid encryption/hashing algorithms: " + getValidEncHashAlgos();
+
+    enum Parameter {
+        adminuser, adminpass, encryption, mpasswdfile
+    }
+
+    private final Map<Parameter, String> parameters = new EnumMap<>(GenerateMasterPasswordCLT.Parameter.class);
+
+    /**
+     * Initializes a new {@link GenerateMasterPasswordCLT}.
+     */
+    public GenerateMasterPasswordCLT() {
+        super();
+    }
+
+    @Override
+    protected Void invoke(Options option, CommandLine cmd, Map<Parameter, String> context) throws Exception {
+        File file = new File(context.get(Parameter.mpasswdfile));
+        System.out.println((file.createNewFile() ? "Created a new file in '" : "Using already existing file '") + file.getAbsolutePath() + "'");
         StringBuilder builder = new StringBuilder();
-        Map<Parameter, String> parameters = new HashMap<Parameter, String>();
-        initParameters(parameters);
         boolean printUsage = false;
         String exceptionMessage = "";
         try {
-            CommandLine cl = parser.parse(options, args);
-            if (cl.hasOption("h")) {
-                printUsage(0);
+            List<String> lines = readPasswordFile(file, context);
+            writePasswordFile(file, lines);
+            builder.append("Saved password for user '").append(context.get(Parameter.adminuser)).append("' and encryption '").append(context.get(Parameter.encryption)).append("' in '").append(context.get(Parameter.mpasswdfile)).append("'.");
+            System.out.println(builder.toString());
+            return null;
+        } catch (IOException e) {
+            exceptionMessage = e.getMessage();
+        }
+        builder.append("Unable to save password for user '").append(context.get(Parameter.adminuser)).append("' and encryption '").append(context.get(Parameter.encryption)).append("' in '").append(context.get(Parameter.mpasswdfile)).append("'.");
+        builder.append("\n").append(exceptionMessage);
+        System.err.println(builder.toString());
+        if (printUsage) {
+            printUsage(-1);
+        }
+
+        return null;
+    }
+
+    @Override
+    protected void addOptions(Options options) {
+        options.addOption(createOption("A", "adminuser", true, "master Admin user name (Default: oxadminmaster)", false));
+        options.addOption(createOption("P", "adminpass", true, "master Admin password", false));
+        options.addOption(createOption("f", "mpasswdfile", true, "Path to mpasswd (Default: /opt/open-xchange/etc/mpasswd)", false));
+        options.addOption(createOption("e", "encryption", true, "Encryption algorithm to use for the password (Default: bcrypt)", false));
+        options.addOption(createOption("h", "help", false, "Prints this help text", false));
+    }
+
+    @Override
+    protected void checkOptions(CommandLine cmd) {
+        initParameters();
+        StringBuilder builder = new StringBuilder();
+
+        boolean printUsage = false;
+        String exceptionMessage = "";
+        try {
+            if (cmd.hasOption("A")) {
+                parameters.put(Parameter.adminuser, cmd.getOptionValue("A"));
             }
-            if (cl.hasOption("A")) {
-                parameters.put(Parameter.adminuser, cl.getOptionValue("A"));
-            }
-            if (cl.hasOption("e")) {
-                parameters.put(Parameter.encryption, cl.getOptionValue("e"));
+            if (cmd.hasOption("e")) {
+                String mechId = cmd.getOptionValue("e");
+                getPasswordMechFor(mechId);
+                parameters.put(Parameter.encryption, mechId);
             }
             String clearPassword;
-            if (cl.hasOption("P")) {
-                clearPassword = cl.getOptionValue("P");
+            if (cmd.hasOption("P")) {
+                clearPassword = cmd.getOptionValue("P");
             } else {
                 builder.append("Enter password for user ").append(parameters.get(Parameter.adminuser)).append(": ");
                 Console console = System.console();
@@ -153,26 +174,20 @@ public class GenerateMasterPasswordCLT {
                     clearPassword = bufferRead.readLine();
                 }
             }
-            final String encPassword = encryptPassword(parameters.get(Parameter.encryption), clearPassword);
+            String encPassword = encryptPassword(parameters.get(Parameter.encryption), clearPassword);
             clearPassword = null;
             parameters.put(Parameter.adminpass, encPassword);
-            if (cl.hasOption("f")) {
-                parameters.put(Parameter.mpasswdfile, cl.getOptionValue("f"));
+            if (cmd.hasOption("f")) {
+                parameters.put(Parameter.mpasswdfile, cmd.getOptionValue("f"));
             }
-
-            builder.setLength(0);
-
-            invoke(parameters);
-            builder.append("Saved password for user '").append(parameters.get(Parameter.adminuser)).append("' and encryption '").append(parameters.get(Parameter.encryption)).append("' in '").append(parameters.get(Parameter.mpasswdfile)).append("'.");
-            System.out.println(builder.toString());
-            System.exit(0);
-        } catch (ParseException | IllegalArgumentException | OXException e) {
+            return;
+        } catch (IllegalArgumentException | OXException e) {
             exceptionMessage = e.getMessage();
             printUsage = true;
         } catch (IOException e) {
             exceptionMessage = e.getMessage();
         }
-        builder.append("Unable to save password for user '").append(parameters.get(Parameter.adminuser)).append("' and encryption '").append(parameters.get(Parameter.encryption)).append("' in '").append(parameters.get(Parameter.mpasswdfile)).append("'.");
+
         builder.append("\n").append(exceptionMessage);
         System.err.println(builder.toString());
         if (printUsage) {
@@ -180,51 +195,78 @@ public class GenerateMasterPasswordCLT {
         }
     }
 
+    @Override
+    protected String getFooter() {
+        return FOOTER;
+    }
+
+    @Override
+    protected String getName() {
+        return SYNTAX;
+    }
+
+    @Override
+    protected Map<Parameter, String> getContext() {
+        return parameters;
+    }
+
+    ///////////////////////////////////// HELPERS ////////////////////////////////
+
     /**
-     * Invoke
+     * Reads the specified password file
      *
-     * @param parameters
-     * @throws IOException
-     * @throws FileNotFoundException
+     * @param file The file to read
+     * @param context a map with the command line values for adminuser, encryption and adminpass
+     * @return A {@link List} with the lines of the file
+     * @throws FileNotFoundException If the file is not found
+     * @throws IOException if an I/O error is occurred
      */
-    private static void invoke(Map<Parameter, String> parameters) throws IOException {
-        File file = new File(parameters.get(Parameter.mpasswdfile));
-        boolean created = file.createNewFile();
-        if (created) {
-            System.out.println("Created a new file in '" + file.getAbsolutePath() + "'");
-        } else {
-            System.err.println("Using already existing file '" + file.getAbsolutePath() + "'");
-        }
-
-        BufferedReader br = null;
-        PrintWriter writer = null;
-        try {
-            br = new BufferedReader(new FileReader(file));
-
+    private List<String> readPasswordFile(File file, Map<Parameter, String> context) throws FileNotFoundException, IOException {
+        try (BufferedReader br = new BufferedReader(new InputStreamReader(new FileInputStream(file), Charsets.UTF_8))) {
             List<String> lines = new LinkedList<String>();
             boolean updated = false;
+            StringBuilder builder = new StringBuilder(96);
             for (String line; (line = br.readLine()) != null;) {
-                if (!line.startsWith("#") && !Strings.isEmpty(line)) {
-                    lines.add(new StringBuilder(96).append(parameters.get(Parameter.adminuser)).append(":").append(parameters.get(Parameter.encryption)).append(":").append(parameters.get(Parameter.adminpass)).toString());
+                if (!line.startsWith("#") && Strings.isNotEmpty(line)) {
+                    lines.add(builder.append(context.get(Parameter.adminuser)).append(":").append(context.get(Parameter.encryption)).append(":").append(context.get(Parameter.adminpass)).toString());
                     updated = true;
                 } else {
                     lines.add(line);
                 }
+                builder.setLength(0);
             }
 
             if (!updated) {
-                lines.add(new StringBuilder(96).append(parameters.get(Parameter.adminuser)).append(":").append(parameters.get(Parameter.encryption)).append(":").append(parameters.get(Parameter.adminpass)).toString());
+                lines.add(builder.append(context.get(Parameter.adminuser)).append(":").append(context.get(Parameter.encryption)).append(":").append(context.get(Parameter.adminpass)).toString());
             }
+            return lines;
+        }
+    }
 
-            writer = new PrintWriter(file);
+    /**
+     * Writes the specified lines to the specified file
+     *
+     * @param file The file to write to
+     * @param lines The lines to write to the file
+     */
+    private void writePasswordFile(File file, List<String> lines) {
+        boolean error = true;
+        try (Writer writer = new BufferedWriter(new OutputStreamWriter(new FileOutputStream(file), Charsets.UTF_8));) {
             for (String line : lines) {
-                writer.println(line);
+                writer.append(line).append(Strings.getLineSeparator());
             }
             writer.flush();
+            error = false;
+        } catch (UnsupportedEncodingException e) {
+            System.err.println("Unsupported encoding: 'UTF-8'");
         } catch (FileNotFoundException e) {
-            throw e;
+            System.err.println("File not found: '" + file.getAbsolutePath() + "'");
+        } catch (IOException e) {
+            System.err.println("I/O error occurred: '" + e.getMessage() + "'");
         } finally {
-            Streams.close(br, writer);
+            if (error) {
+                System.exit(-1);
+            }
         }
     }
 
@@ -237,17 +279,15 @@ public class GenerateMasterPasswordCLT {
      * @throws OXException
      * @throws IllegalArgumentException if the request encryption algorithm string is either <code>null</code>, or empty, or unknown
      */
-    private static String encryptPassword(final String encryption, final String password) throws OXException {
+    private String encryptPassword(final String encryption, final String password) throws OXException {
         IPasswordMech pm = getPasswordMechFor(encryption);
         return pm.encode(password);
     }
 
     /**
      * Initialise defaults
-     *
-     * @param parameters
      */
-    private static void initParameters(Map<Parameter, String> parameters) {
+    private void initParameters() {
         parameters.put(Parameter.adminuser, "oxadminmaster");
         parameters.put(Parameter.adminpass, null);
         parameters.put(Parameter.encryption, "bcrypt");
@@ -259,10 +299,8 @@ public class GenerateMasterPasswordCLT {
      *
      * @param exitCode
      */
-    private static final void printUsage(int exitCode) {
-        HelpFormatter hf = new HelpFormatter();
-        hf.setWidth(120);
-        hf.printHelp("generatempasswd [-A <adminuser>] [-P <adminpassword>] [-e <encryption>] [-f </path/for/mpasswdfile>]", null, options, "\n\nValid encryption/hashing algorithms: " + getValidEncHashAlgos());
+    private final void printUsage(int exitCode) {
+        printHelp();
         System.exit(exitCode);
     }
 
@@ -287,7 +325,7 @@ public class GenerateMasterPasswordCLT {
      * @return The password mechanism
      * @throws IllegalArgumentException if the identifier is either <code>null</code>, or empty, or unknown
      */
-    public static IPasswordMech getPasswordMechFor(String identifier) {
+    private IPasswordMech getPasswordMechFor(String identifier) {
         if (Strings.isEmpty(identifier)) {
             throw new IllegalArgumentException("The identifier for the password mechanism can neither be 'null' nor empty.");
         }
