@@ -190,7 +190,7 @@ public abstract class DatabaseAbstraction extends UtilAbstraction {
                 }
             }
         } else {
-            if (!Strings.isEmpty(tmp)) {
+            if (Strings.isNotEmpty(tmp)) {
                 throw new InvalidDataException("\"" + OPT_NAME_NUMBER_OF_SCHMEMAS_LONG + "\" option can only be set, if \"" + OPT_NAME_CREATE_SCHMEMAS_LONG + "\" is set to \"true\"");
             }
             numberOfSchemas = Integer.valueOf(0);
@@ -265,7 +265,7 @@ public abstract class DatabaseAbstraction extends UtilAbstraction {
                     throw new InvalidDataException(e);
                 }
             }
-            db.setUrl("jdbc:mysql://" + hostname + "/?useUnicode=true&characterEncoding=UTF-8&autoReconnect=false&useUnicode=true&useServerPrepStmts=false&useTimezone=true&serverTimezone=UTC&connectTimeout=15000&socketTimeout=15000");
+            db.setUrl("jdbc:mysql://" + hostname);
         }
     }
 
