@@ -8,7 +8,7 @@
  *
  *    In some countries OX, OX Open-Xchange, open xchange and OXtender
  *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the Open-Xchange, Inc. group of companies.
+ *    trademarks of the OX Software GmbH group of companies.
  *    The use of the Logos is not covered by the GNU General Public License.
  *    Instead, you are allowed to use these Logos according to the terms and
  *    conditions of the Creative Commons License, Version 2.5, Attribution,
@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2014 Open-Xchange, Inc.
+ *     Copyright (C) 2016-2020 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -52,6 +52,7 @@ package com.openexchange.admin.osgi;
 import org.osgi.framework.BundleContext;
 import org.osgi.framework.ServiceReference;
 import org.osgi.util.tracker.ServiceTrackerCustomizer;
+import com.openexchange.admin.services.AdminServiceRegistry;
 import com.openexchange.admin.storage.sqlStorage.OXAdminPoolInterface;
 import com.openexchange.database.DatabaseService;
 
@@ -74,7 +75,11 @@ public class DatabaseServiceCustomizer implements ServiceTrackerCustomizer<Datab
     @Override
     public DatabaseService addingService(ServiceReference<DatabaseService> reference) {
         DatabaseService service = context.getService(reference);
-        pool.setService(service);
+        if (service != null) {
+            pool.setService(service);
+            AdminServiceRegistry.getInstance().addService(DatabaseService.class, service);
+        }
+
         return service;
     }
 
@@ -86,6 +91,7 @@ public class DatabaseServiceCustomizer implements ServiceTrackerCustomizer<Datab
     @Override
     public void removedService(ServiceReference<DatabaseService> reference, DatabaseService service) {
         pool.removeService();
+        AdminServiceRegistry.getInstance().removeService(DatabaseService.class);
         context.ungetService(reference);
     }
 }
