@@ -58,8 +58,10 @@ import java.rmi.RemoteException;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Collections;
+import java.util.LinkedHashMap;
 import java.util.LinkedHashSet;
 import java.util.List;
+import java.util.Map;
 import java.util.Set;
 import java.util.concurrent.ExecutionException;
 import java.util.regex.Pattern;
@@ -67,6 +69,7 @@ import org.osgi.framework.BundleContext;
 import com.openexchange.admin.daemons.ClientAdminThread;
 import com.openexchange.admin.daemons.ClientAdminThreadExtended;
 import com.openexchange.admin.plugins.OXContextPluginInterface;
+import com.openexchange.admin.plugins.OXContextPluginInterfaceExtended;
 import com.openexchange.admin.plugins.PluginException;
 import com.openexchange.admin.rmi.OXContextInterface;
 import com.openexchange.admin.rmi.dataobjects.Context;
@@ -96,7 +99,6 @@ import com.openexchange.admin.services.PluginInterfaces;
 import com.openexchange.admin.storage.interfaces.OXContextStorageInterface;
 import com.openexchange.admin.storage.interfaces.OXUserStorageInterface;
 import com.openexchange.admin.storage.interfaces.OXUtilStorageInterface;
-import com.openexchange.admin.storage.utils.Filestore2UserUtil;
 import com.openexchange.admin.taskmanagement.TaskManager;
 import com.openexchange.admin.tools.AdminCache;
 import com.openexchange.admin.tools.DatabaseDataMover;
@@ -475,8 +477,9 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
 
     @Override
     public void delete(final Context ctx, final Credentials credentials) throws RemoteException, InvalidCredentialsException, NoSuchContextException, StorageException, DatabaseUpdateException, InvalidDataException {
-        if (null == ctx) {
-            InvalidDataException e = new InvalidDataException("Context is null");
+        try {
+            doNullCheck(ctx);
+        } catch (InvalidDataException e) {
             LOGGER.error("", e);
             throw e;
         }
@@ -507,23 +510,60 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
 
             final OXContextStorageInterface oxcox = OXContextStorageInterface.getInstance();
 
-            // Trigger plugin extensions
+            // Trigger plug-in extensions for pre-deletion
+            Map<OXContextPluginInterfaceExtended, Map<String, Object>> undeleteInfos = null;
             {
                 final PluginInterfaces pluginInterfaces = PluginInterfaces.getInstance();
                 if (null != pluginInterfaces) {
-                    for (final OXContextPluginInterface oxContextPlugin : pluginInterfaces.getContextPlugins().getServiceList()) {
-                        try {
-                            oxContextPlugin.delete(ctx, auth);
-                        } catch (final PluginException e) {
-                            LOGGER.error("", e);
-                            throw StorageException.wrapForRMI(e);
+                    List<OXContextPluginInterface> plugins = pluginInterfaces.getContextPlugins().getServiceList();
+                    for (final OXContextPluginInterface oxContextPlugin : plugins) {
+                        if (oxContextPlugin instanceof OXContextPluginInterfaceExtended) {
+                            OXContextPluginInterfaceExtended extended = (OXContextPluginInterfaceExtended) oxContextPlugin;
+                            try {
+                                Map<String, Object> undoInfo = extended.undoableDelete(ctx, auth);
+                                if (undoInfo != null) {
+                                    if (undeleteInfos == null) {
+                                        undeleteInfos = new LinkedHashMap<OXContextPluginInterfaceExtended, Map<String,Object>>(plugins.size());
+                                    }
+                                    undeleteInfos.put(extended, undoInfo);
+                                }
+                            } catch (final PluginException e) {
+                                LOGGER.error("", e);
+                                throw StorageException.wrapForRMI(e);
+                            }
+                        } else {
+                            try {
+                                oxContextPlugin.delete(ctx, auth);
+                            } catch (final PluginException e) {
+                                LOGGER.error("", e);
+                                throw StorageException.wrapForRMI(e);
+                            }
+                        }
+                    }
+                }
+            }
+
+            if (undeleteInfos == null) {
+                oxcox.delete(ctx);
+            } else {
+                boolean deleted = false;
+                try {
+                    oxcox.delete(ctx);
+                    deleted = true;
+                } finally {
+                    if (!deleted) {
+                        for (Map.Entry<OXContextPluginInterfaceExtended, Map<String, Object>> undeleteInfo : undeleteInfos.entrySet()) {
+                            try {
+                                Map<String, Object> undoInfo = undeleteInfo.getValue();
+                                undeleteInfo.getKey().undelete(ctx, undoInfo);
+                            } catch (PluginException x) {
+                                LOGGER.warn("Undeletion failed", x);
+                            }
                         }
                     }
                 }
             }
 
-            oxcox.delete(ctx);
-            Filestore2UserUtil.removeFilestore2UserEntries(ctx.getId().intValue(), cache);
             basicAuthenticator.removeFromAuthCache(ctx);
         } catch (final StorageException e) {
             LOGGER.error("", e);
