@@ -52,6 +52,7 @@ import java.io.Serializable;
 import java.util.Hashtable;
 import com.openexchange.admin.rmi.exceptions.DuplicateExtensionException;
 import com.openexchange.admin.rmi.extensions.OXCommonExtension;
+import com.openexchange.admin.rmi.extensions.OXCommonExtensionInterface;
 
 /**
  * This class defines all those methods which make and object capable of being dynamically extended by other
@@ -66,9 +67,7 @@ public abstract class ExtendableDataObject extends EnforceableDataObject impleme
 
     private static final long serialVersionUID = 5125311385480887183L;
 
-    private Hashtable<String, OXCommonExtension> extensions = null;
-
-    private final boolean extensionsset = false;
+    private Hashtable<String, OXCommonExtensionInterface> extensions = null;
 
     /**
      * This field is used to show if all extension have run fine and inserted their
@@ -82,7 +81,7 @@ public abstract class ExtendableDataObject extends EnforceableDataObject impleme
      * @param extension An {@link OXCommonExtension} object
      * @throws DuplicateExtensionException
      */
-    public void addExtension(final OXCommonExtension extension) throws DuplicateExtensionException {
+    public void addExtension(final OXCommonExtensionInterface extension) throws DuplicateExtensionException {
         final String extensionName = extension.getClass().getName();
         if (this.extensions.containsKey(extensionName)) {
             throw new DuplicateExtensionException(extensionName);
@@ -95,7 +94,7 @@ public abstract class ExtendableDataObject extends EnforceableDataObject impleme
      *
      * @return A {@link Hashtable}
      */
-    public Hashtable<String, OXCommonExtension> getAllExtensionsAsHash() {
+    public Hashtable<String, OXCommonExtensionInterface> getAllExtensionsAsHash() {
         return this.extensions;
     }
 
@@ -107,7 +106,7 @@ public abstract class ExtendableDataObject extends EnforceableDataObject impleme
      * @param extname
      * @return
      */
-    public OXCommonExtension getFirstExtensionByName(final String extname) {
+    public OXCommonExtensionInterface getFirstExtensionByName(final String extname) {
         return this.extensions.get(extname);
     }
 
@@ -122,15 +121,6 @@ public abstract class ExtendableDataObject extends EnforceableDataObject impleme
         return extensionsok;
     }
 
-    /**
-     * This method will be used in the future
-     *
-     * @return
-     */
-    public boolean isExtensionsset() {
-        return extensionsset;
-    }
-
     /**
      * Removes the given extension from this object. Note that only the name of the Class is interesting here
      * so you don't have to provide the exact Object but only an Object from the fitting type.
@@ -151,14 +141,14 @@ public abstract class ExtendableDataObject extends EnforceableDataObject impleme
     }
 
     protected void initExtendable() {
-        this.extensions = new Hashtable<String, OXCommonExtension>(3);
+        this.extensions = new Hashtable<String, OXCommonExtensionInterface>(3);
     }
 
     @Override
     protected Object clone() throws CloneNotSupportedException {
         final ExtendableDataObject object = (ExtendableDataObject) super.clone();
         if( this.extensions != null ) {
-            object.extensions = new Hashtable<String, OXCommonExtension>(this.extensions);
+            object.extensions = new Hashtable<String, OXCommonExtensionInterface>(this.extensions);
         }
         return object;
     }
@@ -166,7 +156,7 @@ public abstract class ExtendableDataObject extends EnforceableDataObject impleme
     @Override
     public String toString() {
         final StringBuilder ret = new StringBuilder(super.toString());
-        for (final OXCommonExtension usrext : extensions.values()) {
+        for (final OXCommonExtensionInterface usrext : extensions.values()) {
             ret.append("  ");
             ret.append("Extension ");
             ret.append(usrext.getClass().getName());
@@ -188,7 +178,6 @@ public abstract class ExtendableDataObject extends EnforceableDataObject impleme
         int result = super.hashCode();
         result = prime * result + ((extensions == null) ? 0 : extensions.hashCode());
         result = prime * result + (extensionsok ? 1231 : 1237);
-        result = prime * result + (extensionsset ? 1231 : 1237);
         return result;
     }
 
@@ -217,9 +206,6 @@ public abstract class ExtendableDataObject extends EnforceableDataObject impleme
         if (extensionsok != other.extensionsok) {
             return false;
         }
-        if (extensionsset != other.extensionsset) {
-            return false;
-        }
         return true;
     }
 }
