@@ -104,9 +104,9 @@ public class CreateCalendarTables extends AbstractCreateTableImpl {
         + "INDEX (cid, intfield02),"
         + "INDEX (cid, timestampfield01),"
         + "INDEX (cid, timestampfield02),"
-        + "INDEX `uidIndex` (cid, uid(255)),"
+        + "INDEX `uidIndex` (cid, uid(191)),"
         + "INDEX `changingDateIndex` (cid, changing_date)"
-        + ") ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;";
+        + ") ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;";
 
     /**
      * Table name of prg_date_rights table
@@ -124,7 +124,7 @@ public class CreateCalendarTables extends AbstractCreateTableImpl {
         + "ma VARCHAR(286),"
         + "dn VARCHAR(320),"
         + "PRIMARY KEY (cid, object_id, id, type)"
-        + ") ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;";
+        + ") ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;";
 
     /**
      * Table name of del_date_rights table
@@ -142,7 +142,7 @@ public class CreateCalendarTables extends AbstractCreateTableImpl {
         + "ma VARCHAR(286),"
         + "dn VARCHAR(320),"
         + "PRIMARY KEY (cid, object_id, id, type)"
-        + ") ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;";
+        + ") ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;";
 
     /**
      * Table name of del_dates table
@@ -189,9 +189,9 @@ public class CreateCalendarTables extends AbstractCreateTableImpl {
         + "INDEX (cid, intfield02),"
         + "INDEX (cid, timestampfield01),"
         + "INDEX (cid, timestampfield02),"
-        + "INDEX `uidIndex` (cid, uid(255)),"
+        + "INDEX `uidIndex` (cid, uid(191)),"
         + "INDEX `changingDateIndex` (cid, changing_date)"
-        + ") ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;";
+        + ") ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;";
 
     /**
      * Table name of del_dates_members table
@@ -212,7 +212,7 @@ public class CreateCalendarTables extends AbstractCreateTableImpl {
         + "PRIMARY KEY (cid, object_id, member_uid, pfid),"
         + "UNIQUE INDEX member (cid, member_uid, object_id),"
         + "INDEX `givenname` (cid, pfid)"
-        + ") ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;";
+        + ") ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;";
 
     /**
      * Table name of prg_dates_members table
@@ -233,7 +233,7 @@ public class CreateCalendarTables extends AbstractCreateTableImpl {
         + "PRIMARY KEY (cid, object_id, member_uid, pfid),"
         + "UNIQUE INDEX member (cid, member_uid, object_id),"
         + "INDEX `givenname` (cid, pfid)"
-        + ") ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;";
+        + ") ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;";
 
     /**
      * Table name of dateExternal table
@@ -246,12 +246,12 @@ public class CreateCalendarTables extends AbstractCreateTableImpl {
     private static final String CREATE_DATE_EXTERNAL = "CREATE TABLE " + TABLE_DATE_EXTERNAL + " ("
         + "cid INT4 UNSIGNED NOT NULL,"
         + "objectId INT4 UNSIGNED NOT NULL,"
-        + "mailAddress VARCHAR(255) NOT NULL,"
+        + "mailAddress VARCHAR(255) CHARACTER SET utf8 COLLATE utf8_unicode_ci NOT NULL,"
         + "displayName VARCHAR(255),"
         + "confirm INT4 UNSIGNED NOT NULL,"
         + "reason TEXT,"
         + "PRIMARY KEY (cid,objectId,`mailAddress`(255))"
-        + ") ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;";
+        + ") ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;";
 
     /**
      * Table name of delDateExternal table
@@ -264,12 +264,12 @@ public class CreateCalendarTables extends AbstractCreateTableImpl {
     private static final String CREATE_DEL_DATE_EXTERNAL = "CREATE TABLE " + TABLE_DEL_DATE_EXTERNAL + " ("
         + "cid INT4 UNSIGNED NOT NULL,"
         + "objectId INT4 UNSIGNED NOT NULL,"
-        + "mailAddress VARCHAR(255) NOT NULL,"
+        + "mailAddress VARCHAR(255) CHARACTER SET utf8 COLLATE utf8_unicode_ci NOT NULL,"
         + "displayName VARCHAR(255),"
         + "confirm INT4 UNSIGNED NOT NULL,"
         + "reason TEXT,"
         + "PRIMARY KEY (cid,objectId,`mailAddress`(255))"
-        + ") ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;";
+        + ") ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;";
 
     /**
      * Initializes a new {@link CreateCalendarTables}.
