@@ -370,7 +370,7 @@ public class OXUtil extends OXCommonImpl implements OXUtilInterface {
         }
 
         if (null == db.getUrl()) {
-            db.setUrl("jdbc:mysql://" + DEFAULT_HOSTNAME + "/?useUnicode=true&characterEncoding=UTF-8&autoReconnect=false&useUnicode=true&useServerPrepStmts=false&useTimezone=true&serverTimezone=UTC&connectTimeout=15000&socketTimeout=15000");
+            db.setUrl("jdbc:mysql://" + DEFAULT_HOSTNAME);
         }
 
         boolean bCreateSchemas = null != createSchemas && createSchemas.booleanValue();
@@ -491,11 +491,13 @@ public class OXUtil extends OXCommonImpl implements OXUtilInterface {
         if (!tool.existsDatabase(i(database.getId()))) {
             throw new InvalidDataException("No such database " + database);
         }
-        if (tool.poolInUse(i(database.getId()))) {
+
+        boolean isMaster = tool.isMasterDatabase(i(database.getId()));
+        if (isMaster && tool.poolInUse(i(database.getId()))) {
             throw new StorageException("Pool is in use " + database);
         }
 
-        oxutil.unregisterDatabase(i(database.getId()), tool.isMasterDatabase(i(database.getId())));
+        oxutil.unregisterDatabase(i(database.getId()), isMaster);
     }
 
     @Override
