@@ -176,6 +176,17 @@ public class OXAdminPoolDBPool implements OXAdminPoolInterface {
         }.perform(getService());
     }
 
+    @Override
+    public Connection getWriteConnectionForConfigDBNoTimeout() throws PoolException {
+        return new DatabaseServiceCallable<Connection>() {
+
+            @Override
+            protected Connection doPerform(DatabaseService databaseService) throws OXException {
+                return databaseService.getForUpdateTask();
+            }
+        }.perform(getService());
+    }
+
     @Override
     public Connection getConnectionForContext(final int contextId) throws PoolException {
         return new DatabaseServiceCallable<Connection>() {
@@ -260,6 +271,23 @@ public class OXAdminPoolDBPool implements OXAdminPoolInterface {
         }.perform(getService()).booleanValue();
     }
 
+    @Override
+    public boolean pushWriteConnectionForConfigDBNoTimeout(final Connection con) throws PoolException {
+        if (null == con) {
+            return false;
+        }
+
+        return new DatabaseServiceCallable<Boolean>() {
+
+            @Override
+            protected Boolean doPerform(DatabaseService databaseService) throws OXException {
+                Databases.autocommit(con);
+                databaseService.backForUpdateTask(con);
+                return Boolean.TRUE;
+            }
+        }.perform(getService()).booleanValue();
+    }
+
     @Override
     public boolean pushConnectionForContext(final int contextId, final Connection con) throws PoolException {
         if (null == con) {
@@ -386,12 +414,12 @@ public class OXAdminPoolDBPool implements OXAdminPoolInterface {
     }
 
     @Override
-    public int[] listContexts(final int poolId) throws PoolException {
+    public int[] listContexts(final int poolId, final int offset, final int length) throws PoolException {
         return new DatabaseServiceCallable<int[]>() {
 
             @Override
             protected int[] doPerform(DatabaseService databaseService) throws OXException {
-                return databaseService.listContexts(poolId);
+                return databaseService.listContexts(poolId, offset, length);
             }
         }.perform(getService());
     }
